@@ -1,27 +1,27 @@
 MapGAM.version = function() cat('
-Jul 12 2023 	MapGAM version 1.3
+Aug 03 2025 	MapGAM version 1.3-1
   	
-Dec 11 2016	AIC.modgam.R
-Jul 12 2023	MapGAM.version.R
-Dec 11 2016	coef.gamcox.R
-Dec 11 2016	coef.modgam.R
+Dec 10 2016	AIC.modgam.R
+Dec 10 2016	coef.gamcox.R
+Dec 10 2016	coef.modgam.R
 May 25 2022	colormap.R
 Oct 16 2016	dls.R
-Dec 11 2016	formula.gamcox.R
-Dec 11 2016	formula.modgam.R
-Nov 1 2018	gamcox.R
-Oct 31 2018	gamcox.fit.R
+Dec 10 2016	formula.gamcox.R
+Dec 10 2016	formula.modgam.R
+Aug 3 2025	gamcox.fit.R
+Aug 3 2025	gamcox.R
+Aug 3 2025	MapGAM.version.R
 Aug 10 2019	modgam.R
 Jul 24 2019	mypredict.gam.R
-Nov 1 2018	optspan.R
+Oct 31 2018	optspan.R
 Jul 27 2019	plot.modgam.R
 Jul 12 2023	predgrid.R
 Oct 20 2016	predict.gamcox.R
 Dec 8 2016	print.gamcox.R
 Dec 8 2016	print.modgam.R
-Dec 11 2016	residuals.gamcox.R
-Dec 11 2016	residuals.modgam.R
-May 24 2022	sampcont.R
+Dec 10 2016	residuals.gamcox.R
+Dec 10 2016	residuals.modgam.R
+Jul 12 2023	sampcont.R
 Aug 10 2019	summary.gamcox.R
 Aug 10 2019	summary.modgam.R
 Sep 18 2017	toformula.R
