@@ -1,7 +1,7 @@
 #***********************************************************************************
 #
 # Trim a Data Set To Map Boundaries 
-# Copyright (C) 2016, 2022, The University of California, Irvine
+# Copyright (C) 2016, 2022, 2023, The University of California, Irvine
 #
 # This library is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,14 +18,25 @@
 #
 #*******************************************************************************
 trimdata <- function(rdata, map, Xcol=2, Ycol=3, rectangle=F, buffer=0.05) {
-	if(inherits(map,"SpatialPolygonsDataFrame")) {
-		mappoly=SpatialPolygons2PolySet(map) 
-		mr = c(range(mappoly$X),range(mappoly$Y))	# map range
-	} else 
-	if (inherits(map,"map")) {
-		map_sp = map2SpatialLines(map,proj4string=CRS("+proj=longlat +datum=WGS84"))	
-		mappoly=SpatialLines2PolySet(map_sp)
-		mr = map$range		# map range
+	if (inherits(map,"Spatial") | inherits(map,"Raster")) {  
+		mrmat <- bbox(map)
+        Xrange <- mrmat[1,]
+        Yrange <- mrmat[2,]
+        mr <- c(Xrange,Yrange)
+        centroid <- data.frame(X=mean(Xrange),Y=mean(Yrange)) 
+    }
+    else if (inherits(map,"sf")) {
+      	mrsf = st_bbox(map)
+      	Xrange = mrsf[c(1,3)]
+      	Yrange = mrsf[c(2,4)]
+        mr <- c(Xrange,Yrange)
+        centroid <- data.frame(X=mean(Xrange),Y=mean(Yrange)) 
+    }
+    else if (inherits(map,"map")) {
+      	mr = map$range
+      	Xrange = mr[1:2]
+      	Yrange = mr[3:4]
+        centroid <- data.frame(X=mean(Xrange),Y=mean(Yrange)) 
 	} else
 		stop(paste("map class not recognized by trimdata function"))
 	# if rdata has only 2 columns assign them as X and Y
@@ -39,19 +50,15 @@ trimdata <- function(rdata, map, Xcol=2, Ycol=3, rectangle=F, buffer=0.05) {
 	dataYmax=max(rdata[,Ycol])
 	dr = c(dataXmin,dataXmax,dataYmin,dataYmax)		# data range
 	
-	# Print warning if the map centroid is not within the data range
-	# only works if PBSmapping library is loaded
-	if (requireNamespace("PBSmapping", quietly = TRUE)) {
-      centroid = PBSmapping::calcCentroid(PBSmapping::combinePolys(mappoly),rollup=1)[-1]
+	# Print warning if the map bbox centroid is not within the data range
 	  mapmean=(dataXmin<centroid$X)+(centroid$X<dataXmax)+(dataYmin<centroid$Y)+(centroid$Y<dataYmax)
-	  if (mapmean!=4) {				
+	if (mapmean!=4) {				
 		warning("The map centroid is not in the range of the data.  This might indicate differing projections.")
 		cat(paste(c("Data X: "," to ","; Data Y: "," to "),signif(dr,digits=4),sep="",collapse=""),fill=TRUE)
 		cat(paste(c("Map X: "," to ","; Map Y: "," to "),signif(mr,digits=4),sep="",collapse=""),fill=TRUE)
 		cat(paste(c("Map centroid: ",", "),signif(centroid,digits=4),sep="",collapse=""),fill=TRUE)
-	  }
 	}
-	if (rectangle==T) { 
+	if (rectangle==T | inherits(map,"Raster")) { 
 		# Keep subset of data within a rectangular boundary using map coordinate ranges
 		if (length(buffer)<=2) buffer = rep(c(mr[2]-mr[1],mr[4]-mr[3])*buffer,each=2) 
 		mr = mr + c(-1,1,-1,1)*buffer
@@ -59,15 +66,18 @@ trimdata <- function(rdata, map, Xcol=2, Ycol=3, rectangle=F, buffer=0.05) {
 		cat(paste(c("Data trimmed to rectangle on X: "," to "," and Y: "," to "),
 				signif(mr,digits=4),sep="",collapse=""),fill=TRUE)
 	} else {
-		# Keep subset of data within strict boundaries of map
-		rdn = names(rdata)
-		rdata$EID = 1:length(rdata[,1])
-		names(rdata)[c(Xcol,Ycol)] = c("X","Y")
-		maped=PBSmapping::as.EventData(rdata)
-		mapfind=PBSmapping::findPolys(maped,mappoly)$EID	
-		rdata = rdata[rdata$EID %in% mapfind,]
-		rdata = rdata[,!(names(rdata) %in% "EID")]	# keep all but EID variable
-		names(rdata) = rdn							# restore original variable names
+		# Keep subset of data within boundaries of map
+		map.sf <- st_as_sf(map)
+		rdata_sf <- rdata
+		if (!inherits(rdata,"sf")) {
+			mapcrs <- st_crs(map.sf)
+			rdata_sf <- st_as_sf(rdata,coords=c(Xcol,Ycol),crs=mapcrs)
+			cat(paste(c("Data assumed to use same CRS as map:",mapcrs)), fill=T)
+			}
+		if(inherits(map,"map")) sf_use_s2(FALSE)     # fix errors when using maps library
+		inside <- lengths(st_intersects(rdata_sf,map.sf)) > 0
+		rdata <- na.omit(rdata[inside,])
+		sf_use_s2(TRUE)
 	}
 	return(rdata)
 }
